@@ -36,13 +36,6 @@
 extern Prefs p;
 
 Theme theme[] = {
-  {
-   N_("Classic"),
-   "tileset_50x50_sunspot.svg",
-   NULL,
-   "#9999CC",
-   N_("Red"), N_("Yellow")
-   },
   {
    N_("High Contrast"),
    "tileset_50x50_hcontrast.svg",
@@ -58,32 +51,25 @@ Theme theme[] = {
    N_("Circle"), N_("Cross")
    },
   {
-   N_("Cream Marbles"),
-   "tileset_50x50_catseyes.png",
+   N_("Red and Green Marbles"),
+   "tileset_50x50_faenza-glines-icon1.svg",
    "bg_toplight.png",
    "#727F8C",
-   N_("Red"), N_("Blue")
+   N_("Red"), N_("Green")
    },
   {
-   N_("Glass Marbles"),
-   "tileset_50x50_glassy.png",
-   "bg_grotty.jpg",
+   N_("Blue and Red Marbles"),
+   "tileset_50x50_faenza-glines-icon2.svg",
+   "bg_toplight.png",
    "#727F8C",
-   N_("Red"), N_("Blue")
+   N_("Blue"), N_("Red")
    },
   {
-   N_("Nightfall"),
-   "tileset_50x50_glassy.png",
-   "bg_nightfall.jpg",
+   N_("Stars and Rings"),
+   "tileset_50x50_faenza-gnect-icon.svg",
+   "bg_toplight.png",
    "#727F8C",
-   N_("Red"), N_("Blue")
-   },
-  {
-   N_("Blocks"),
-   "tileset_50x50_square.png",
-   NULL,
-   "#666666",
-   N_("Orange"), N_("Blue")
+   N_("Red"), N_("Green")
    }
 };
 
